@@ -26,7 +26,8 @@ sub attributes {
 		$a->H3,
 		$a->H4,
 		$a->H5,
-		$a->H6
+		$a->H6,
+		$a->IMAGE
 	);
 }
 
@@ -123,6 +124,12 @@ sub add_h6 {
 	return $self;
 }
 
+sub add_image {
+	my ($self, %args) = @_;
+	$self->image->add($self, %args);
+	return $self;
+}
+
 sub save {
 	my ($self) = shift;
 	$self->pdf->saveas();
